@@ -14,7 +14,9 @@ from requests.models import Request
 from localstack import config
 from localstack.config import ServiceProviderConfig
 from localstack.utils.bootstrap import get_enabled_apis, is_api_enabled, log_duration
-from localstack.utils.common import call_safe, poll_condition, wait_for_port_status
+from localstack.utils.functions import call_safe
+from localstack.utils.net import wait_for_port_status
+from localstack.utils.sync import poll_condition
 
 # set up logger
 LOG = logging.getLogger(__name__)
@@ -131,7 +133,7 @@ class ServiceLifecycleHook:
         pass
 
 
-class Service(object):
+class Service:
     def __init__(
         self,
         name,
@@ -483,6 +485,17 @@ class ServicePluginManager(ServiceManager):
             if self.get_active_provider(service) in providers
         ]
 
+    def list_loaded_services(self) -> List[str]:
+        """
+        Lists all the services which have a provider that has been initialized
+        :return: a list of service names
+        """
+        return [
+            service
+            for service in self.list_available()
+            if super(ServicePluginManager, self).get_service_container(service)
+        ]
+
     def exists(self, name: str) -> bool:
         return name in self.list_available()
 
